#!/bin/bash
# Script to run make with input target and arguments

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

do_buildstep_prepend

unset CFLAGS CPPFLAGS CXXFLAGS LDFLAGS
if [ "${BUILD_REPRODUCIBLE_BINARIES}" = "1" ]; then
	export KCONFIG_NOTIMESTAMP=1
fi
if [ "${BUSYBOX_SPLIT_SUID}" = "1" -a x`grep "CONFIG_FEATURE_INDIVIDUAL=y" .config` = x ]; then
	# split the .config into two parts, and make two busybox binaries
	if [ -e .config.orig ]; then
		# Need to guard again an interrupted do_compile - restore any backup
		log_exec cp .config.orig .config
	fi
	log_exec cp .config .config.orig
	do_make busybox.cfg.suid
	do_make busybox.cfg.nosuid

	# workaround for suid bug 10346
	if ! grep -q "CONFIG_SH_IS_NONE" busybox.cfg.nosuid; then
		echo "CONFIG_SH_IS_NONE" >> busybox.cfg.suid
	fi

	for i in `cat busybox.cfg.suid busybox.cfg.nosuid`; do
		echo "# $i is not set" >> .config.disable.apps
	done
	merge_config.sh -m .config.orig .config.disable.apps
	cp .config .config.nonapps
	for s in suid nosuid; do
		cat busybox.cfg.$s | while read item; do
			grep -w "$item" .config.orig
		done > .config.app.$s

		# workaround for suid bug 10346
		if [ "$s" = "suid" ] ; then
			sed "s/.*CONFIG_SH_IS_NONE.*$/CONFIG_SH_IS_NONE=y/" -i .config.app.suid
		fi

		merge_config.sh -m .config.nonapps .config.app.$s
		do_make busybox_unstripped
		log_exec mv busybox_unstripped busybox.$s
		do_make busybox.links
		sort busybox.links > busybox.links.$s
		log_exec rm busybox.links
	done

	# hard fail if sh is being linked to the suid busybox (detects bug 10346)
	if grep -q -x "/bin/sh" busybox.links.suid; then
		fatal "busybox suid binary incorrectly provides /bin/sh"
	fi

	# copy .config.orig back to .config, because the install process may check this file
	log_exec cp .config.orig .config
	# cleanup
	log_exec rm .config.orig .config.app.suid .config.app.nosuid .config.disable.apps .config.nonapps
else
	do_make busybox_unstripped
	log_exec cp busybox_unstripped busybox
	do_make busybox.links
fi

do_buildstep_append
